summaryrefslogtreecommitdiff
path: root/include/ouroboros/ipcp.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ouroboros/ipcp.h')
-rw-r--r--include/ouroboros/ipcp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/ouroboros/ipcp.h b/include/ouroboros/ipcp.h
index 11e2699b..b9f6b1ff 100644
--- a/include/ouroboros/ipcp.h
+++ b/include/ouroboros/ipcp.h
@@ -35,7 +35,7 @@
*/
enum ipcp_type {
IPCP_LOCAL = 0,
- IPCP_NORMAL,
+ IPCP_UNICAST,
IPCP_BROADCAST,
IPCP_RAPTOR,
IPCP_ETH_LLC,
@@ -44,7 +44,7 @@ enum ipcp_type {
IPCP_INVALID
};
/* Normal IPCP policies */
enum pol_addr_auth {
ADDR_AUTH_FLAT_RANDOM = 0
};
@@ -78,7 +78,7 @@ struct ipcp_config {
enum ipcp_type type;
- /* Normal */
+ /* Unicast */
uint8_t addr_size;
uint8_t eid_size;
uint8_t max_ttl;
@@ -44,7 +44,7 @@ enum ipcp_type {
IPCP_INVALID
};
-/* Normal IPCP policies */
+/* Unicast IPCP policies */
enum pol_addr_auth {
ADDR_AUTH_FLAT_RANDOM = 0